@@ -62,7 +62,7 @@ Highlighter_init(Highlighter *self, Searcher *searcher, Obj *query,
     ivars->slop           = excerpt_length / 3;
     ivars->pre_tag        = Str_new_from_trusted_utf8("<strong>", 8);
     ivars->post_tag       = Str_new_from_trusted_utf8("</strong>", 9);
-    if (Query_Is_A(ivars->query, COMPILER)) {
+    if (Query_is_a(ivars->query, COMPILER)) {
         ivars->compiler = (Compiler*)INCREF(ivars->query);
     }
     else {
@@ -155,7 +155,7 @@ Highlighter_Create_Excerpt_IMP(Highlighter *self, HitDoc *hit_doc) {
     String *field_val = (String*)HitDoc_Extract(hit_doc, ivars->field);
     String *retval;
 
-    if (!field_val || !Obj_Is_A((Obj*)field_val, STRING)) {
+    if (!field_val || !Obj_is_a((Obj*)field_val, STRING)) {
         retval = NULL;
     }
     else if (!Str_Get_Size(field_val)) {
@@ -166,11 +166,11 @@ Highlighter_Create_Excerpt_IMP(Highlighter *self, HitDoc *hit_doc) {
         DocVector *doc_vec
             = Searcher_Fetch_Doc_Vec(ivars->searcher,
                                      HitDoc_Get_Doc_ID(hit_doc));
-        VArray *maybe_spans
+        Vector *maybe_spans
             = Compiler_Highlight_Spans(ivars->compiler, ivars->searcher,
                                        doc_vec, ivars->field);
-        VArray *score_spans = maybe_spans ? maybe_spans : VA_new(0);
-        VA_Sort(score_spans, NULL, NULL);
+        Vector *score_spans = maybe_spans ? maybe_spans : Vec_new(0);
+        Vec_Sort(score_spans);
         HeatMap *heat_map
             = HeatMap_new(score_spans, (ivars->excerpt_length * 2) / 3);
 
@@ -197,9 +197,9 @@ static int32_t
 S_hottest(HeatMap *heat_map) {
     float max_score = 0.0f;
     int32_t retval = 0;
-    VArray *spans = HeatMap_Get_Spans(heat_map);
-    for (uint32_t i = VA_Get_Size(spans); i--;) {
-        Span *span = (Span*)VA_Fetch(spans, i);
+    Vector *spans = HeatMap_Get_Spans(heat_map);
+    for (uint32_t i = Vec_Get_Size(spans); i--;) {
+        Span *span = (Span*)Vec_Fetch(spans, i);
         if (Span_Get_Weight(span) >= max_score) {
             retval = Span_Get_Offset(span);
             max_score = Span_Get_Weight(span);
@@ -226,9 +226,9 @@ S_find_starting_boundary(StringIterator *top, uint32_t max_skip,
     while (true) {
         int32_t code_point = StrIter_Prev(iter);
 
-        if (code_point == STRITER_DONE || code_point == '.') {
+        if (code_point == STR_OOB || code_point == '.') {
             // Skip remaining whitespace.
-            *num_skipped_ptr = StrIter_Skip_Next_Whitespace(top);
+            *num_skipped_ptr = StrIter_Skip_Whitespace(top);
             DECREF(iter);
             return true;
         }
@@ -251,7 +251,7 @@ S_find_starting_boundary(StringIterator *top, uint32_t max_skip,
     for (uint32_t i = 0; i < max_skip; ++i) {
         int32_t code_point = StrIter_Next(iter);
 
-        if (code_point == STRITER_DONE || code_point == '.') {
+        if (code_point == STR_OOB || code_point == '.') {
             found_edge = true;
             StrIter_Assign(top, iter);
             num_skipped = i + 1;
@@ -271,7 +271,7 @@ S_find_starting_boundary(StringIterator *top, uint32_t max_skip,
     }
 
     // Skip remaining whitespace.
-    num_skipped += StrIter_Skip_Next_Whitespace(top);
+    num_skipped += StrIter_Skip_Whitespace(top);
     *num_skipped_ptr = num_skipped;
 
     DECREF(word);
@@ -296,9 +296,9 @@ S_find_ending_boundary(StringIterator *tail, uint32_t max_skip,
     do {
         code_point = StrIter_Next(iter);
 
-        if (code_point == STRITER_DONE) {
+        if (code_point == STR_OOB) {
             // Skip remaining whitespace.
-            *num_skipped_ptr = StrIter_Skip_Prev_Whitespace(tail);
+            *num_skipped_ptr = StrIter_Skip_Whitespace_Back(tail);
             DECREF(iter);
             return true;
         }
@@ -311,7 +311,7 @@ S_find_ending_boundary(StringIterator *tail, uint32_t max_skip,
     StrIter_Assign(iter, tail);
 
     for (uint32_t i = 0;
-         STRITER_DONE != (code_point = StrIter_Prev(iter));
+         STR_OOB != (code_point = StrIter_Prev(iter));
          ++i)
     {
         if (code_point == '.') {
@@ -345,7 +345,7 @@ S_find_ending_boundary(StringIterator *tail, uint32_t max_skip,
         StrIter_Assign(tail, word);
 
         // Strip whitespace and punctuation that collides with an ellipsis.
-        while (STRITER_DONE != (code_point = StrIter_Prev(tail))) {
+        while (STR_OOB != (code_point = StrIter_Prev(tail))) {
             if (!StrHelp_is_whitespace(code_point)
                 && code_point != '.'
                 && code_point != ','
@@ -434,7 +434,7 @@ Highlighter_Raw_Excerpt_IMP(Highlighter *self, String *field_val,
         raw_excerpt = Str_new_from_trusted_utf8("", 0);
     }
     else {
-        String  *substring = StrIter_substring(top, tail);
+        String  *substring = StrIter_crop(top, tail);
         CharBuf *buf       = CB_new(Str_Get_Size(substring) + 8);
 
         // If not starting on a sentence boundary, prepend an ellipsis.
@@ -465,7 +465,7 @@ Highlighter_Raw_Excerpt_IMP(Highlighter *self, String *field_val,
 }
 
 String*
-Highlighter_Highlight_Excerpt_IMP(Highlighter *self, VArray *spans,
+Highlighter_Highlight_Excerpt_IMP(Highlighter *self, Vector *spans,
                                   String *raw_excerpt, int32_t top) {
     int32_t         hl_start        = 0;
     int32_t         hl_end          = 0;
@@ -475,8 +475,8 @@ Highlighter_Highlight_Excerpt_IMP(Highlighter *self, VArray *spans,
     CharBuf        *encode_buf      = NULL;
     int32_t         raw_excerpt_end = top + Str_Length(raw_excerpt);
 
-    for (uint32_t i = 0, max = VA_Get_Size(spans); i < max; i++) {
-        Span *span = (Span*)VA_Fetch(spans, i);
+    for (uint32_t i = 0, max = Vec_Get_Size(spans); i < max; i++) {
+        Span *span = (Span*)Vec_Fetch(spans, i);
         int32_t offset = Span_Get_Offset(span);
         if (offset < top) {
             continue;
@@ -499,7 +499,7 @@ Highlighter_Highlight_Excerpt_IMP(Highlighter *self, VArray *spans,
                     int32_t highlighted_len = hl_end - hl_start;
                     StrIter_Assign(temp, iter);
                     StrIter_Advance(iter, highlighted_len);
-                    String *to_cat = StrIter_substring(temp, iter);
+                    String *to_cat = StrIter_crop(temp, iter);
                     String *encoded = S_do_encode(self, to_cat, &encode_buf);
                     String *hl_frag = Highlighter_Highlight(self, encoded);
                     CB_Cat(buf, hl_frag);
@@ -511,7 +511,7 @@ Highlighter_Highlight_Excerpt_IMP(Highlighter *self, VArray *spans,
                 int32_t non_highlighted_len = relative_start - hl_end;
                 StrIter_Assign(temp, iter);
                 StrIter_Advance(iter, non_highlighted_len);
-                String *to_cat = StrIter_substring(temp, iter);
+                String *to_cat = StrIter_crop(temp, iter);
                 String *encoded = S_do_encode(self, to_cat, &encode_buf);
                 CB_Cat(buf, (String*)encoded);
                 DECREF(encoded);
@@ -528,7 +528,7 @@ Highlighter_Highlight_Excerpt_IMP(Highlighter *self, VArray *spans,
         int32_t highlighted_len = hl_end - hl_start;
         StrIter_Assign(temp, iter);
         StrIter_Advance(iter, highlighted_len);
-        String *to_cat = StrIter_substring(temp, iter);
+        String *to_cat = StrIter_crop(temp, iter);
         String *encoded = S_do_encode(self, to_cat, &encode_buf);
         String *hl_frag = Highlighter_Highlight(self, encoded);
         CB_Cat(buf, hl_frag);
@@ -539,7 +539,7 @@ Highlighter_Highlight_Excerpt_IMP(Highlighter *self, VArray *spans,
 
     // Last text, beyond last highlight span.
     if (StrIter_Has_Next(iter)) {
-        String *to_cat = StrIter_substring(iter, NULL);
+        String *to_cat = StrIter_crop(iter, NULL);
         String *encoded = S_do_encode(self, to_cat, &encode_buf);
         CB_Cat(buf, encoded);
         DECREF(encoded);
@@ -565,7 +565,7 @@ Highlighter_Encode_IMP(Highlighter *self, String *text) {
 
 static String*
 S_do_encode(Highlighter *self, String *text, CharBuf **encode_buf) {
-    Class *klass = Highlighter_Get_Class(self);
+    Class *klass = Highlighter_get_class(self);
     Highlighter_Encode_t my_meth
         = (Highlighter_Encode_t)METHOD_PTR(klass, LUCY_Highlighter_Encode);
     Highlighter_Encode_t orig_meth
@@ -588,7 +588,7 @@ S_encode_entities(String *text, CharBuf *buf) {
 
     // Scan first so that we only allocate once.
     int32_t code_point;
-    while (STRITER_DONE != (code_point = StrIter_Next(iter))) {
+    while (STR_OOB != (code_point = StrIter_Next(iter))) {
         if (code_point > 127
             || (!isgraph(code_point) && !isspace(code_point))
             || code_point == '<'
@@ -603,11 +603,11 @@ S_encode_entities(String *text, CharBuf *buf) {
         }
     }
 
+    CB_Clear(buf);
     CB_Grow(buf, space);
-    CB_Set_Size(buf, 0);
     DECREF(iter);
     iter = Str_Top(text);
-    while (STRITER_DONE != (code_point = StrIter_Next(iter))) {
+    while (STR_OOB != (code_point = StrIter_Next(iter))) {
         if (code_point > 127
             || (!isgraph(code_point) && !isspace(code_point))
            ) {
