@@ -35,6 +35,9 @@
 #include "Lucy/Store/Folder.h"
 #include "Lucy/Store/InStream.h"
 #include "Lucy/Store/OutStream.h"
+#include "Lucy/Util/NumberUtils.h"
+#include "Clownfish/Blob.h"
+#include "Clownfish/Num.h"
 #include "Clownfish/Util/Memory.h"
 #include "Clownfish/Util/SortUtils.h"
 
@@ -126,11 +129,11 @@ SortFieldWriter_init(SortFieldWriter *self, Schema *schema,
         ivars->var_width = true;
     }
     else if (ivars->prim_id == FType_BLOB) {
-        ivars->mem_per_entry += Class_Get_Obj_Alloc_Size(BYTEBUF);
+        ivars->mem_per_entry += Class_Get_Obj_Alloc_Size(BLOB);
         ivars->var_width = true;
     }
     else {
-        ivars->mem_per_entry += Class_Get_Obj_Alloc_Size(FLOAT64);
+        ivars->mem_per_entry += Class_Get_Obj_Alloc_Size(FLOAT);
         ivars->var_width = false;
     }
 
@@ -180,7 +183,7 @@ SortFieldWriter_Add_IMP(SortFieldWriter *self, int32_t doc_id, Obj *value) {
         Counter_Add(counter, size);
     }
     else if (ivars->prim_id == FType_BLOB) {
-        int64_t size = BB_Get_Size((ByteBuf*)value) + 1;
+        int64_t size = Blob_Get_Size((Blob*)value) + 1;
         size = SI_increase_to_word_multiple(size);
         Counter_Add(counter, size);
     }
@@ -266,31 +269,31 @@ S_write_val(Obj *val, int8_t prim_id, OutStream *ix_out, OutStream *dat_out,
                     break;
                 }
             case FType_BLOB: {
-                    ByteBuf *byte_buf = (ByteBuf*)val;
+                    Blob *blob = (Blob*)val;
                     int64_t dat_pos = OutStream_Tell(dat_out) - dat_start;
                     OutStream_Write_I64(ix_out, dat_pos);
-                    OutStream_Write_Bytes(dat_out, BB_Get_Buf(byte_buf),
-                                          BB_Get_Size(byte_buf));
+                    OutStream_Write_Bytes(dat_out, Blob_Get_Buf(blob),
+                                          Blob_Get_Size(blob));
                     break;
                 }
             case FType_INT32: {
-                    Integer32 *i32 = (Integer32*)val;
-                    OutStream_Write_I32(dat_out, Int32_Get_Value(i32));
+                    int32_t i32 = (int32_t)Int_Get_Value((Integer*)val);
+                    OutStream_Write_I32(dat_out, i32);
                     break;
                 }
             case FType_INT64: {
-                    Integer64 *i64 = (Integer64*)val;
-                    OutStream_Write_I64(dat_out, Int64_Get_Value(i64));
-                    break;
-                }
-            case FType_FLOAT64: {
-                    Float64 *float64 = (Float64*)val;
-                    OutStream_Write_F64(dat_out, Float64_Get_Value(float64));
+                    int64_t i64 = Int_Get_Value((Integer*)val);
+                    OutStream_Write_I64(dat_out, i64);
                     break;
                 }
             case FType_FLOAT32: {
-                    Float32 *float32 = (Float32*)val;
-                    OutStream_Write_F32(dat_out, Float32_Get_Value(float32));
+                    float f32 = (float)Float_Get_Value((Float*)val);
+                    OutStream_Write_F32(dat_out, f32);
+                    break;
+                }
+            case FType_FLOAT64: {
+                    double f64 = Float_Get_Value((Float*)val);
+                    OutStream_Write_F64(dat_out, f64);
                     break;
                 }
             default:
@@ -324,10 +327,10 @@ S_write_val(Obj *val, int8_t prim_id, OutStream *ix_out, OutStream *dat_out,
 }
 
 int
-SortFieldWriter_Compare_IMP(SortFieldWriter *self, void *va, void *vb) {
+SortFieldWriter_Compare_IMP(SortFieldWriter *self, Obj **ptr_a, Obj **ptr_b) {
     SortFieldWriterIVARS *const ivars = SortFieldWriter_IVARS(self);
-    SFWriterElemIVARS *a = SFWriterElem_IVARS(*(SFWriterElem**)va);
-    SFWriterElemIVARS *b = SFWriterElem_IVARS(*(SFWriterElem**)vb);
+    SFWriterElemIVARS *a = SFWriterElem_IVARS(*(SFWriterElem**)ptr_a);
+    SFWriterElemIVARS *b = SFWriterElem_IVARS(*(SFWriterElem**)ptr_b);
     int32_t comparison
         = FType_null_back_compare_values(ivars->type, a->value, b->value);
     if (comparison == 0) { comparison = a->doc_id - b->doc_id; }
@@ -481,7 +484,7 @@ void
 SortFieldWriter_Flip_IMP(SortFieldWriter *self) {
     SortFieldWriterIVARS *const ivars = SortFieldWriter_IVARS(self);
     uint32_t num_items = SortFieldWriter_Buffer_Count(self);
-    uint32_t num_runs = VA_Get_Size(ivars->runs);
+    uint32_t num_runs = Vec_Get_Size(ivars->runs);
 
     if (ivars->flipped) { THROW(ERR, "Can't call Flip() twice"); }
     ivars->flipped = true;
@@ -517,7 +520,7 @@ SortFieldWriter_Flip_IMP(SortFieldWriter *self) {
         size_t sub_thresh = ivars->mem_thresh / num_runs;
         if (sub_thresh < 65536) { sub_thresh = 65536; }
         for (uint32_t i = 0; i < num_runs; i++) {
-            SortFieldWriter *run = (SortFieldWriter*)VA_Fetch(ivars->runs, i);
+            SortFieldWriter *run = (SortFieldWriter*)Vec_Fetch(ivars->runs, i);
             S_flip_run(run, sub_thresh, ivars->ord_in, ivars->ix_in,
                        ivars->dat_in);
         }
